==> AgeOn1.6.5_source.zip: AgeOn1.6.5_source/nispi/OptionControl/OutWard/Tab/OutWardDataTab2.cs <==
﻿//ライセンス情報はAgeOnフォルダのLISENCEフォルダを参照してください
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading;
using System.Drawing;

namespace nispi.OptionControl
{
    partial class OutWardTabData : CommonInEvent
    {
        public byte TabColorStartRed
        {
            set
            {
                //if (CheckBool(value) == false) return;
                mutex.WaitOne();
                this.tabColorStartRed = value;
                mutex.ReleaseMutex();
            }
            get
            {
                mutex.WaitOne();
                byte data = this.tabColorStartRed;
                mutex.ReleaseMutex();
                return data;
            }
        }
        public byte TabColorStartGreen
        {
            set
            {
                //if (CheckBool(value) == false) return;
                mutex.WaitOne();
                this.tabColorStartGreen = value;
                mutex.ReleaseMutex();
            }
            get
            {
                mutex.WaitOne();
                byte data = this.tabColorStartGreen;
                mutex.ReleaseMutex();
                return data;
            }
        }
        public byte TabColorStartBlue
        {
            set
            {
                //if (CheckBool(value) == false) return;
                mutex.WaitOne();
                this.tabColorStartBlue = value;
                mutex.ReleaseMutex();
            }
            get
            {
                mutex.WaitOne();
                byte data = this.tabColorStartBlue;
                mutex.ReleaseMutex();
                return data;
            }
        }
        public byte TabColorEndRed
        {
            set
            {
                //if (CheckBool(value) == false) return;
                mutex.WaitOne();
                this.tabColorEndRed = value;
                mutex.ReleaseMutex();
            }
            get
            {
                mutex.WaitOne();
                byte data = this.tabColorEndRed;
                mutex.ReleaseMutex();
                return data;
            }
        }
        public byte TabColorEndGreen
        {
            set
            {
                //if (CheckBool(value) == false) return;
                mutex.WaitOne();
                this.tabColorEndGreen = value;
                mutex.ReleaseMutex();
            }
            get
            {
                mutex.WaitOne();
                byte data = this.tabColorEndGreen;
                mutex.ReleaseMutex();
                return data;
            }
        }
        public byte TabColorEndBlue
        {
            set
            {
                //if (CheckBool(value) == false) return;
                mutex.WaitOne();
                this.tabColorEndBlue= value;
                mutex.ReleaseMutex();
            }
            get
            {
                mutex.WaitOne();
                byte data = this.tabColorEndBlue;
                mutex.ReleaseMutex();
                return data;
            }
        }

    }
}

==> AgeOn2.5_source.zip: AgeOn2.5_source/nispi/OptionControl/OutWard/Tab/OutWardDataTab2.cs <==
﻿//ライセンス情報はAgeOnフォルダのLISENCEフォルダを参照してください
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading;
using System.Drawing;

namespace nispi.OptionControl
{
    partial class OutWardTabData : CommonInEvent
    {
        public byte TabSelectedColorRed
        {
            set
            {
                //if (CheckBool(value) == false) return;
                mutex.WaitOne();
                this.tabSelectedColorRed = value;
                mutex.ReleaseMutex();
            }
            get
            {
                mutex.WaitOne();
                byte data = this.tabSelectedColorRed;
                mutex.ReleaseMutex();
                return data;
            }
        }
        public byte TabSelectedColorGreen
        {
            set
            {
                //if (CheckBool(value) == false) return;
                mutex.WaitOne();
                this.tabSelectedColorGreen = value;
                mutex.ReleaseMutex();
            }
            get
            {
                mutex.WaitOne();
                byte data = this.tabSelectedColorGreen;
                mutex.ReleaseMutex();
                return data;
            }
        }
        public byte TabSelectedColorBlue
        {
            set
            {
                //if (CheckBool(value) == false) return;
                mutex.WaitOne();
                this.tabSelectedColorBlue = value;
                mutex.ReleaseMutex();
            }
            get
            {
                mutex.WaitOne();
                byte data = this.tabSelectedColorBlue;
                mutex.ReleaseMutex();
                return data;
            }
        }
        public byte TabHotColorRed
        {
            set
            {
                //if (CheckBool(value) == false) return;
                mutex.WaitOne();
                this.tabHotColorRed = value;
                mutex.ReleaseMutex();
            }
            get
            {
                mutex.WaitOne();
                byte data = this.tabHotColorRed;
                mutex.ReleaseMutex();
                return data;
            }
        }
        public byte TabHotColorGreen
        {
            set
            {
                //if (CheckBool(value) == false) return;
                mutex.WaitOne();
                this.tabHotColorGreen = value;
                mutex.ReleaseMutex();
            }
            get
            {
                mutex.WaitOne();
                byte data = this.tabHotColorGreen;
                mutex.ReleaseMutex();
                return data;
            }
        }
        public byte TabHotColorBlue
        {
            set
            {
                //if (CheckBool(value) == false) return;
                mutex.WaitOne();
                this.tabHotColorBlue= value;
                mutex.ReleaseMutex();
            }
            get
            {
                mutex.WaitOne();
                byte data = this.tabHotColorBlue;
                mutex.ReleaseMutex();
                return data;
            }
        }

    }
}
